#ifndef ADDAPPLICATION_H
#define ADDAPPLICATION_H

#include "BAddApplication.h"

class AddApplication : public BAddApplication
{ 
    Q_OBJECT

public:
    AddApplication( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~AddApplication();

};

#endif // ADDAPPLICATION_H
